Issues
======
How to Name an Issue
--------------------
1. Name issues `succinctly <http://www.investmentwriting.com/2011/03/omit-needless-words-excerpt-from-strunks-the-elements-of-style/>`_
2. Word issues as a command. Example: **Add View for Namespace Entries**
3. Include eloquent descriptions of the task if you do not plan on doing it yourself
4. Include lots of references so a general audience (bosses, people working on other projects, etc.) can find relevant material

Issues that are explicitly not appropriate for BEL Commons
----------------------------------------------------------
- Development of the BEL language
- The functionality of the PyBEL Parser
- Generation and maintenance of BEL content
